@@ -4,32 +4,32 @@
 
 class Configuration:
     # The version number of the transformer
-    transformer_version = None
+    TRANSFORMER_VERSION = None
 
     # The transformer description
-    transformer_description = None
+    TRANSFORMER_DESCRIPTION = None
 
     # Short name of the transformer
-    transformer_name = None
+    TRANSFORMER_NAME = None
 
     # The sensor associated with the transformer
-    transformer_sensor = None
+    TRANSFORMER_SENSOR = None
 
     # The transformer type (eg: 'rgbmask', 'plotclipper')
-    transformer_type = None
+    TRANSFORMER_TYPE = None
 
     # The name of the author of the extractor
-    author_name = None
+    AUTHOR_NAME = None
 
     # The email of the author of the extractor
-    author_email = None
+    AUTHOR_EMAIL = None
 
     # Contributors to this transformer
-    contributors = []
+    CONTRUBUTORS = []
 
     # Repository URI of where the source code lives
-    repository = None
+    REPOSITORY = None
 
     # Override flag for disabling the metadata file requirement.
     # Uncomment and set to False to override default behavior
-    # metadata_needed = True
+    # METADATA_NEEDED = True
